ECPoint class

Elliptic curve point

Constructors

ECPoint(BigInt x, BigInt y, {bool isInfinity = false})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isInfinity → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → BigInt
final
y → BigInt
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator *(BigInt scalar) → ECPoint
Scalar multiplication
operator +(ECPoint other) → ECPoint
Point addition
operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

infinity → ECPoint
Point at infinity
final