EdDSASignature class

EdDSA signature structure

Constructors

EdDSASignature(Uint8List R, Uint8List S)
const
EdDSASignature.fromBytes(Uint8List bytes)
Creates signature from bytes (64 bytes total)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
R → Uint8List
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
S → Uint8List
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
Converts signature to bytes (64 bytes total)
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited