RIPEMD160 class

RIPEMD-160 hash algorithm implementation

Constructors

RIPEMD160()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

hash(String data) String
Computes RIPEMD-160 hash of the input string
override
hashBytes(Uint8List data) String
Computes RIPEMD-160 hash of the input bytes
hashRaw(Uint8List data) Uint8List
Computes RIPEMD-160 hash and returns raw bytes