RIPEMD160Constants class

RIPEMD-160 hash constants and initial values

Constructors

RIPEMD160Constants()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

h List<int>
no setter
k1 List<int>
no setter
k2 List<int>
no setter
r1 List<int>
no setter
r2 List<int>
no setter
s1 List<int>
no setter
s2 List<int>
no setter