Scrypt class

Scrypt key derivation function implementation

Constructors

Scrypt()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

deriveKey(String password, String salt) → Future<String>
Derives a key using scrypt with default parameters
deriveKeyBytes(String password, String salt, {int N = _defaultN, int r = _defaultR, int p = _defaultP, int dkLen = _defaultDkLen}) → Future<Uint8List>
Derives a key using scrypt with custom parameters