ActorCritic class

Constructors

ActorCritic({required int nActions, required List<int> actorLayers, required List<int> criticLayers, int? seed})

Properties

actor → ANN
final
critic → ANN
final
hashCode → int
The hash code for this object.
no setterinherited
nActions → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
selectAction(List<double> state) → int
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
update(List<double> state, int action, double reward, List<double> nextState, {double actorLr = 0.01, double criticLr = 0.01}) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(String s, {int? seed}) → ActorCritic
fromMap(Map<String, dynamic> m, {int? seed}) → ActorCritic