Autoencoder class

Constructors

Autoencoder(int hidden, {int epochs = 100, double lr = 0.01})

Properties

b1 ↔ List<double>?
getter/setter pair
b2 ↔ List<double>?
getter/setter pair
epochs → int
final
hashCode → int
The hash code for this object.
no setterinherited
hidden → int
final
lr → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
w1 ↔ List<List<double>>?
getter/setter pair
w2 ↔ List<List<double>>?
getter/setter pair

Methods

encode(List<List<double>> X) → List<List<double>>
fit(List<List<double>> X) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited