BayesianOptimization class

Constructors

BayesianOptimization({required List<List<double>> initialX, required List<double> initialY, required List<double> lower, required List<double> upper, int? seed})

Properties

hashCode → int
The hash code for this object.
no setterinherited
initialX → List<List<double>>
final
initialY → List<double>
final
lower → List<double>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upper → List<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optimize({int budget = 20}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

sqrt2 → const double