GAN class

Simple GAN scaffolding using ANN heads for generator and discriminator.

Constructors

GAN({int latentDim = 100, required List<int> genLayers, required List<int> discLayers, int? seed})

Properties

discriminator → ANN
final
generator → ANN
final
hashCode → int
The hash code for this object.
no setterinherited
latentDim → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fit(List<List<double>> realX, {int epochs = 1, int batchSize = 16}) → void
Very small-step adversarial training stub: perform paired updates on discriminator and generator by creating labels and fitting the ANN heads.
generate(int n) → List<List<double>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(String s, {int? seed}) → GAN
fromMap(Map<String, dynamic> m, {int? seed}) → GAN