GMM class

Constructors

GMM(int k, {int maxIter = 100, double tol = 1e-4})

Properties

covs ↔ List<List<double>>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
k → int
final
maxIter → int
final
means ↔ List<List<double>>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tol → double
final
weights ↔ List<double>?
getter/setter pair

Methods

fit(List<List<double>> X) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
predict(List<double> x) → int
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited