GRU class

Minimal GRU wrapper delegating the final mapping to an ANN readout.

Constructors

GRU({required int inputSize, required int hiddenSize, required List<int> readoutLayers, int? seed})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hiddenSize → int
final
inputSize → int
final
readout → ANN
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fit(List<List<List<double>>> X, List<List<double>> Y, {int? batchSize, bool verbose = false}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
predict(List<List<List<double>>> X) → List<List<double>>
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(String s, {int? seed}) → GRU
fromMap(Map<String, dynamic> m, {int? seed}) → GRU