KMeans class

Constructors

KMeans(int k, {int maxIter = 300, double tol = 1e-4})

Properties

centroids ↔ List<List<double>>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
k → int
final
labels ↔ List<int>?
getter/setter pair
maxIter → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tol → double
final

Methods

fit(List<List<double>> X) → void
inertia(List<List<double>> X) → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
predict(List<List<double>> X) → List<int>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited