LinearRegressionModel class

Thin object wrapper around the functional API to provide a uniform fit/predict interface used across the ML modules.

Constructors

LinearRegressionModel()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fit(List<List<double>> X, List<double> y) → void
Fit the model to features X and targets y.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
predict(List<List<double>> X) → List<double>
Predict a list of examples.
predictOne(List<double> features) → double
Predict a single example's target value.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited