LogisticRegressionModel class

Thin adapter providing a fit/predict interface for logistic regression.

Constructors

LogisticRegressionModel()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fit(List<List<double>> X, List<int> y, {double lr = 0.1, int epochs = 500}) → void
Fit the logistic regression model.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
predict(List<List<double>> X) → List<int>
Predict labels for multiple examples.
predictOne(List<double> features) → int
Predict label (0/1) using 0.5 threshold.
predictProba(List<double> features) → double
Predict probability for a single example.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited