MCTSNode<S> class

Constructors

MCTSNode(S state, {MCTSNode? parent, dynamic actionFromParent})

Properties

actionFromParent → dynamic
final
children → List<MCTSNode<S>>
final
hashCode → int
The hash code for this object.
no setterinherited
parent ↔ MCTSNode?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → S
final
value ↔ double
getter/setter pair
visits ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited