MDP class

Constructors

MDP({required int nStates, required int nActions, required List<List<List<double>>> P, required List<List<List<double>>> R})

Properties

hashCode → int
The hash code for this object.
no setterinherited
nActions → int
final
nStates → int
final
P → List<List<List<double>>>
final
R → List<List<List<double>>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
policyIteration({double gamma = 0.99, int maxIter = 1000}) → Map<String, dynamic>
Policy iteration
toString() → String
A string representation of this object.
inherited
valueIteration({double gamma = 0.99, double tol = 1e-6, int maxIter = 10000}) → Map<String, dynamic>
Value iteration: returns pair (values, policy)

Operators

operator ==(Object other) → bool
The equality operator.
inherited