GaussianNB class

Constructors

GaussianNB()

Properties

hashCode → int
The hash code for this object.
no setterinherited
means ↔ Map<int, List<double>>
getter/setter pair
priors ↔ Map<int, double>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variances ↔ Map<int, List<double>>
getter/setter pair

Methods

fit(List<List<double>> X, List<int> y) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
predict(List<double> x) → int
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited