SimulatedAnnealing<T> class

Constructors

SimulatedAnnealing({required T initial, required double energy(T), required T neighbor(T, Random), required double temperature(int), int? seed})

Properties

energy → double Function(T)
final
hashCode → int
The hash code for this object.
no setterinherited
initial → T
final
neighbor → T Function(T, Random)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
temperature → double Function(int)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optimize({int iterations = 1000}) → Map<String, dynamic>
Run optimization for iterations steps. Returns a map with keys:
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited