SVMModel class

Thin wrapper providing fit/predict interface for the linear SVM.

Constructors

SVMModel()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fit(List<List<double>> X, List<int> y, {double lr = 0.01, int epochs = 500, double C = 1.0}) → void
Fit model with labels in {-1, +1}.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
predict(List<List<double>> X) → List<int>
Predict multiple examples.
predictOne(List<double> x) → int
Predict a single example, returning {-1, +1}.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited