BGPRoutingTable<T> class

Represents the BGP routing information base (RIB)

Constructors

BGPRoutingTable({required T sourceAS, required Map<T, BGPRouteEntry<T>> routes, required Map<T, List<BGPRouteEntry<T>>> alternativeRoutes, required DateTime lastUpdate, required int totalRoutes, required int totalASes})
const

Properties

allRoutes → List<BGPRouteEntry<T>>
Gets all routes as a list
no setter
alternativeRoutes → Map<T, List<BGPRouteEntry<T>>>
final
directlyConnectedRoutes → List<BGPRouteEntry<T>>
Gets directly connected routes
no setter
hashCode → int
The hash code for this object.
no setterinherited
lastUpdate → DateTime
final
routeCount → int
Gets the number of routes
no setter
routes → Map<T, BGPRouteEntry<T>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceAS → T
final
totalASes → int
final
totalRoutes → int
final

Methods

getAlternativeRoutes(T destination) → List<BGPRouteEntry<T>>
Gets all alternative routes to a destination
getBestRoute(T destination) → BGPRouteEntry<T>?
Gets the best route to a specific destination
getRoutesByCommunity(String community) → List<BGPRouteEntry<T>>
Gets routes with specific community
getRoutesByOrigin(BGPOrigin origin) → List<BGPRouteEntry<T>>
Gets routes by origin type
getRoutesByPathLength(int maxLength) → List<BGPRouteEntry<T>>
Gets routes with AS path length less than or equal to maxLength
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited