LinkStateDatabase<T> class

Represents a complete link-state database for the network

Constructors

LinkStateDatabase({required Map<T, List<LinkStateEntry<T>>> nodeLinks, required DateTime lastUpdate, required int totalLinks, required int totalNodes})
const

Properties

activeLinkCount → int
Gets the total number of active links
no setter
Gets all active links in the database
no setter
failedLinkCount → int
Gets the total number of failed links
no setter
Gets all failed links in the database
no setter
hashCode → int
The hash code for this object.
no setterinherited
lastUpdate → DateTime
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
final
totalNodes → int
final

Methods

getLinkCost(T source, T target) → num?
Gets the cost of a link between two nodes
getLinksForNode(T node) → List<LinkStateEntry<T>>
Gets all links for a specific node
Checks if a specific link exists between two nodes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited