LinkStateEntry<T> class

Represents a link-state entry with complete network information

Constructors

LinkStateEntry({required T sourceNode, required T targetNode, required num linkCost, required LinkStateStatus status, required DateTime lastUpdate, required int sequenceNumber, Map<String, dynamic> attributes = const {}})
const

Properties

attributes → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setteroverride
isActive → bool
Checks if the link is active and usable
no setter
isBidirectional → bool
Checks if the link is bidirectional
no setter
lastUpdate → DateTime
final
linkCost → num
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber → int
final
sourceNode → T
final
status → LinkStateStatus
final
targetNode → T
final

Methods

copyWith({T? sourceNode, T? targetNode, num? linkCost, LinkStateStatus? status, DateTime? lastUpdate, int? sequenceNumber, Map<String, dynamic>? attributes}) → LinkStateEntry<T>
Creates a copy with updated values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
updateStatus(LinkStateStatus newStatus) → LinkStateEntry<T>
Updates the link status and timestamp

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

maxSequenceNumber → int
Gets the maximum allowed sequence number
no setter