LinkStateRoutingAlgorithm<T> class

Link-State Routing Algorithm implementation

Constructors

LinkStateRoutingAlgorithm({Duration updateInterval = _defaultUpdateInterval, Duration linkTimeout = _linkTimeout, bool enableTopologyOptimization = true, bool enablePathCompression = true})
Creates a link-state routing algorithm instance
const

Properties

enablePathCompression → bool
final
enableTopologyOptimization → bool
final
hashCode → int
The hash code for this object.
no setterinherited
linkTimeout → Duration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateInterval → Duration
final

Methods

computeRoutes(Map<T, Map<T, num>> network, T sourceNode, {Map<String, dynamic>? topologyOptimizations}) → LinkStateRoutingTable<T>
Computes complete routing table using link-state algorithm
getLinkStateStatistics(LinkStateRoutingTable<T> routingTable) → Map<String, dynamic>
Gets comprehensive statistics for monitoring and analysis
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateFromTopologyChanges(LinkStateRoutingTable<T> currentTable, List<LinkStateEntry<T>> topologyChanges, Map<T, Map<T, num>> network) → LinkStateRoutingTable<T>?
Updates routing table based on topology changes
validateLinkStateTable(LinkStateRoutingTable<T> routingTable, Map<T, Map<T, num>> network) → List<String>
Validates link-state routing table consistency

Operators

operator ==(Object other) → bool
The equality operator.
inherited