LinkStateRoutingTable<T> class

Represents a complete link-state routing table

Constructors

LinkStateRoutingTable({required T sourceNode, required Map<T, LinkStateRouteEntry<T>> routes, required LinkStateDatabase<T> topology, required DateTime lastUpdate, required int totalRoutes, required int totalNodes})
const

Properties

activeRoutes → List<LinkStateRouteEntry<T>>
Gets all active routes
no setter
allRoutes → List<LinkStateRouteEntry<T>>
Gets all routes as a list
no setter
directlyConnectedRoutes → List<LinkStateRouteEntry<T>>
Gets directly connected routes
no setter
hashCode → int
The hash code for this object.
no setterinherited
lastUpdate → DateTime
final
routeCount → int
Gets the number of routes
no setter
routes → Map<T, LinkStateRouteEntry<T>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceNode → T
final
topology → LinkStateDatabase<T>
final
totalNodes → int
final
totalRoutes → int
final

Methods

getRoute(T destination) → LinkStateRouteEntry<T>?
Gets the route to a specific destination
getRoutesByCost(num maxCost) → List<LinkStateRouteEntry<T>>
Gets routes with cost less than or equal to maxCost
getRoutesByHopCount(int hopCount) → List<LinkStateRouteEntry<T>>
Gets routes with specific hop count
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited