OSPFAlgorithm<T> class

OSPF Algorithm implementation with area support and link-state database

Constructors

OSPFAlgorithm({Duration lsaInterval = _defaultLSAInterval, Duration lsaExpiry = _defaultLSAExpiry, int maxIterations = 1000, bool enableAreas = true})
Creates an OSPF algorithm instance with configurable parameters
const

Properties

enableAreas → bool
final
hashCode → int
The hash code for this object.
no setterinherited
lsaExpiry → Duration
final
lsaInterval → Duration
final
maxIterations → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cleanupLSDB(Map<T, List<LinkStateAdvertisement<T>>> lsdb, DateTime currentTime) → Map<T, List<LinkStateAdvertisement<T>>>
Performs link-state database maintenance and cleanup
computeRoutes(Map<T, Map<T, num>> network, T sourceRouter, {int areaId = 0}) → OSPFRoutingTable<T>
Computes complete routing table for a source router using Dijkstra's algorithm
getOSPFStatistics(OSPFRoutingTable<T> routingTable, Map<T, List<LinkStateAdvertisement<T>>> lsdb) → Map<String, dynamic>
Gets OSPF statistics for monitoring and analysis
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateFromLSA(OSPFRoutingTable<T> currentTable, LinkStateAdvertisement<T> newLSA, Map<T, Map<T, num>> network) → OSPFRoutingTable<T>?
Updates routing table based on new link-state advertisements
validateOSPFTable(OSPFRoutingTable<T> routingTable, Map<T, Map<T, num>> network) → List<String>
Validates OSPF routing table consistency

Operators

operator ==(Object other) → bool
The equality operator.
inherited