OSPFRouteEntry<T> class

Represents a routing table entry with OSPF-specific information

Constructors

OSPFRouteEntry({required T destination, T? nextHop, required num cost, T? advertisingRouter, required LinkStateType routeType, required DateTime lastUpdate, required bool isDirectlyConnected, int areaId = 0})
const

Properties

advertisingRouter → T?
final
areaId → int
final
cost → num
final
destination → T
final
hashCode → int
The hash code for this object.
no setteroverride
isDirectlyConnected → bool
final
lastUpdate → DateTime
final
nextHop → T?
final
routeType → LinkStateType
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({T? destination, T? nextHop, num? cost, T? advertisingRouter, LinkStateType? routeType, DateTime? lastUpdate, bool? isDirectlyConnected, int? areaId}) → OSPFRouteEntry<T>
Creates a copy with updated values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override