OSPFRoutingTable<T> class

Represents the OSPF routing table with area support

Constructors

OSPFRoutingTable({required T sourceRouter, required Map<T, OSPFRouteEntry<T>> routes, required Map<int, Set<T>> areaRoutes, required DateTime lastUpdate, required int totalAreas})
const

Properties

allRoutes → List<OSPFRouteEntry<T>>
Gets all routes as a list
no setter
areaRoutes → Map<int, Set<T>>
final
directlyConnectedRoutes → List<OSPFRouteEntry<T>>
Gets directly connected routes
no setter
hashCode → int
The hash code for this object.
no setterinherited
lastUpdate → DateTime
final
routeCount → int
Gets the number of routes
no setter
routes → Map<T, OSPFRouteEntry<T>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceRouter → T
final
totalAreas → int
final

Methods

getRoute(T destination) → OSPFRouteEntry<T>?
Gets the route to a specific destination
getRoutesByCost(num maxCost) → List<OSPFRouteEntry<T>>
Gets routes with cost less than or equal to maxCost
getRoutesByType(LinkStateType type) → List<OSPFRouteEntry<T>>
Gets routes by type
getRoutesInArea(int areaId) → List<OSPFRouteEntry<T>>
Gets routes in a specific area
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited