BloomFilterConfig class

Bloom Filter configuration for optimal performance

Constructors

BloomFilterConfig({required int expectedElements, required double falsePositiveRate, required int optimalSize, required int optimalHashFunctions, required List<int> seeds})
const
BloomFilterConfig.custom({required int size, required int hashFunctions, List<int>? seeds})
Creates configuration with custom parameters
factory
BloomFilterConfig.optimal({required int expectedElements, required double falsePositiveRate})
Creates optimal configuration based on expected elements and false positive rate
factory

Properties

expectedElements → int
final
falsePositiveRate → double
final
hashCode → int
The hash code for this object.
no setterinherited
optimalHashFunctions → int
final
optimalSize → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seeds → List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited