ThreadedBinaryTreeNode<T> class

Inheritance

Constructors

ThreadedBinaryTreeNode(T value, {ThreadedBinaryTreeNode<T>? left, ThreadedBinaryTreeNode<T>? right, ThreadedBinaryTreeNode<T>? rightThread})

Properties

hashCode → int
The hash code for this object.
no setterinherited
left ↔ BinaryTreeNode<T>?
getter/setter pairinherited
getter/setter pairinherited
rightThread ↔ ThreadedBinaryTreeNode<T>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited