AStarNode<T> class

Represents a node in the A* search with its f-score (g + h)

Implemented types

Constructors

AStarNode({required T node, T? parent, required num gScore, required num fScore})
const

Properties

fScore → num
final
gScore → num
final
hashCode → int
The hash code for this object.
no setteroverride
node → T
final
parent → T?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(AStarNode<T> other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override