PriorityQueue<T> class

Simple priority queue implementation for A* algorithm

Constructors

PriorityQueue(int _comparator(T a, T b))

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
isNotEmpty → bool
no setter
length → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(T element) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeFirst() → T
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited