DinicsEdge<T> class

Represents a flow network edge with capacity and flow

Constructors

DinicsEdge(T source, T target, num capacity)

Properties

capacity → num
final
flow ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
residualCapacity → num
Returns the residual capacity (remaining capacity)
no setter
reverse → DinicsEdge<T>
Returns the reverse edge for residual graph
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → T
final
target → T
final

Methods

addFlow(num delta) → void
Adds flow to this edge
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited