DinicsResult<T> class

Dinic's algorithm with detailed analysis and performance metrics

Returns comprehensive information about the algorithm execution

Constructors

DinicsResult({required num maxFlow, required Map<T, List<DinicsEdge<T>>> flowNetwork, required int phasesCount, required List<Map<T, int>> layeredNetworks, required List<num> blockingFlows, required Stopwatch executionTime})
const

Properties

averageBlockingFlow → double
Gets the average blocking flow size
no setter
blockingFlows → List<num>
final
executionTime → Stopwatch
final
executionTimeMicros → int
Gets execution time in microseconds
no setter
executionTimeMs → int
Gets execution time in milliseconds
no setter
flowNetwork → Map<T, List<DinicsEdge<T>>>
final
hashCode → int
The hash code for this object.
no setterinherited
layeredNetworks → List<Map<T, int>>
final
maxFlow → num
final
maxLayerDepth → int
Gets the maximum layer depth reached
no setter
phasesCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllFlows() → Map<String, num>
Gets all edges with their flow values
getFlow(T from, T to) → num
Gets the flow value on a specific edge
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited