LayeredNode<T> class

Represents a node in the layered network with its level

Constructors

LayeredNode(T node, int level)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
level → int
final
node → T
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override