TarjansResult<T> class

Result of Tarjan's algorithm containing bridges and articulation points

Constructors

TarjansResult({required List<Bridge<T>> bridges, required Set<T> articulationPoints})
const

Properties

articulationPointCount → int
Gets the number of articulation points found
no setter
articulationPoints → Set<T>
final
bridgeCount → int
Gets the number of bridges found
no setter
bridges → List<Bridge<T>>
final
criticalEdges → List<List<T>>
Gets all critical edges as a list of pairs
no setter
hashCode → int
The hash code for this object.
no setterinherited
is2EdgeConnected → bool
Checks if the graph is 2-edge-connected (no bridges)
no setter
is2VertexConnected → bool
Checks if the graph is 2-vertex-connected (no articulation points)
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited