UnionFindNode<T> class

Represents a node in the Union-Find data structure

Constructors

UnionFindNode(T value)

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent ↔ UnionFindNode<T>?
getter/setter pair
rank ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited