ChordNode class

Constructors

ChordNode(int id, {int m = 32})

Properties

finger List<ChordNode?>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
final
m int
final
predecessor ChordNode?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final
store Map<int, dynamic>
final
successor ChordNode?
getter/setter pair

Methods

closestPrecedingNode(int key) ChordNode
findSuccessor(int key) ChordNode
fixFingers() → void
get(int key) → dynamic
join(ChordNode existing) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify(ChordNode n) → void
put(int key, dynamic value, {int replication = 1}) → void
stabilize() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited