menu
lunaris_engine package
documentation
networkop/min_cost_flow.dart
MinCostFlow class
MinCostFlow class
dark_mode
light_mode
MinCostFlow
class
Constructors
MinCostFlow
(
int
n
)
Properties
g
→
List
<
List
<
MCFEdge
>
>
final
hashCode
→
int
The hash code for this object.
no setter
inherited
n
→
int
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
addEdge
(
int
u
,
int
v
,
int
cap
,
int
cost
)
→ void
minCostMaxFlow
(
int
s
,
int
t
,
int
maxf
)
→
Map
<
String
,
int
>
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
lunaris_engine package
documentation
networkop/min_cost_flow
MinCostFlow class
min_cost_flow library